==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/PopupDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnClosedEventArgsDescriptionMetadata } from "./OnClosedEventArgsDescriptionMetadata";
import { OnPopupEventArgsDescriptionMetadata } from "./OnPopupEventArgsDescriptionMetadata";
import { FocusEventArgsDescriptionMetadata } from "./FocusEventArgsDescriptionMetadata";
import { PopupDescription } from "./PopupDescription";
/**
 * @hidden
 */
export let PopupDescriptionMetadata = /*@__PURE__*/ (() => {
    class PopupDescriptionMetadata extends Base {
        static b(a) {
            if (PopupDescriptionMetadata.a == null) {
                PopupDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PopupDescriptionMetadata.c(PopupDescriptionMetadata.a);
            }
            if (a.k(PopupDescriptionMetadata.a)) {
                return;
            }
            a.ab(PopupDescriptionMetadata.a);
            OnClosedEventArgsDescriptionMetadata.d(a);
            OnPopupEventArgsDescriptionMetadata.d(a);
            FocusEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("IsFocusable", "Boolean");
            a.item("AnimationDuration", "Number:int");
            a.item("AnimationEnabled", "Boolean");
            a.item("AnimationType", "ExportedType:string:PopupAnimationType");
            a.item("AnimationType@names", "GrowShrink;FadeInOutSlide");
            a.item("Elevation", "Number:int");
            a.item("ActualElevation", "Number:int");
            a.item("ActualUmbraShadowColor", "Brush");
            a.item("ActualPenumbraShadowColor", "Brush");
            a.item("ActualAmbientShadowColor", "Brush");
            a.item("Background", "Brush");
            a.item("CornerRadius", "Number:double");
            a.item("IsHitTestVisible", "Boolean");
            a.item("DisableHitTestDuringAnimation", "Boolean");
            a.item("IsPointerEnabled", "Boolean");
            a.item("PointerPosition", "ExportedType:string:PopupPointerPosition");
            a.item("PointerPosition@names", "Top;Bottom");
            a.item("PointerBackground", "Brush");
            a.item("OnClosedRef", "EventRef::onClosed");
            a.item("OnPopupRef", "EventRef::onPopup");
            a.item("PopupGotFocusRef", "EventRef::popupGotFocus");
            a.item("PopupLostFocusRef", "EventRef::popupLostFocus");
        }
        static d(a) {
            PopupDescriptionMetadata.b(a);
            a.ad("Popup", () => new PopupDescription());
            a.ac("Popup", PopupDescriptionMetadata.a);
        }
    }
    PopupDescriptionMetadata.$t = /*@__PURE__*/ markType(PopupDescriptionMetadata, 'PopupDescriptionMetadata');
    PopupDescriptionMetadata.a = null;
    return PopupDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/PopupDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnClosedEventArgsDescriptionMetadata } from "./OnClosedEventArgsDescriptionMetadata";
import { OnPopupEventArgsDescriptionMetadata } from "./OnPopupEventArgsDescriptionMetadata";
import { FocusEventArgsDescriptionMetadata } from "./FocusEventArgsDescriptionMetadata";
import { PopupDescription } from "./PopupDescription";
/**
 * @hidden
 */
export let PopupDescriptionMetadata = /*@__PURE__*/ (() => {
    class PopupDescriptionMetadata extends Base {
        static b(a) {
            if (PopupDescriptionMetadata.a == null) {
                PopupDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PopupDescriptionMetadata.c(PopupDescriptionMetadata.a);
            }
            if (a.k(PopupDescriptionMetadata.a)) {
                return;
            }
            a.ac(PopupDescriptionMetadata.a);
            OnClosedEventArgsDescriptionMetadata.d(a);
            OnPopupEventArgsDescriptionMetadata.d(a);
            FocusEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("IsFocusable", "Boolean");
            a.item("AnimationDuration", "Number:int");
            a.item("AnimationEnabled", "Boolean");
            a.item("AnimationType", "ExportedType:string:PopupAnimationType");
            a.item("AnimationType@names", "GrowShrink;FadeInOutSlide");
            a.item("Elevation", "Number:int");
            a.item("ActualElevation", "Number:int");
            a.item("ActualUmbraShadowColor", "Brush");
            a.item("ActualPenumbraShadowColor", "Brush");
            a.item("ActualAmbientShadowColor", "Brush");
            a.item("Background", "Brush");
            a.item("CornerRadius", "Number:double");
            a.item("IsHitTestVisible", "Boolean");
            a.item("DisableHitTestDuringAnimation", "Boolean");
            a.item("IsPointerEnabled", "Boolean");
            a.item("PointerPosition", "ExportedType:string:PopupPointerPosition");
            a.item("PointerPosition@names", "Auto;Top;Bottom;Left;Right");
            a.item("PointerBackground", "Brush");
            a.item("PointerSize", "Number:double");
            a.item("IsShowing", "Boolean");
            a.item("IsClosing", "Boolean");
            a.item("IsFixed", "Boolean");
            a.item("UseTopLayer", "Boolean");
            a.item("OnClosedRef", "EventRef::onClosed");
            a.item("OnPopupRef", "EventRef::onPopup");
            a.item("PopupGotFocusRef", "EventRef::popupGotFocus");
            a.item("PopupLostFocusRef", "EventRef::popupLostFocus");
        }
        static d(a) {
            PopupDescriptionMetadata.b(a);
            a.ae("Popup", () => new PopupDescription());
            a.ad("Popup", PopupDescriptionMetadata.a);
        }
    }
    PopupDescriptionMetadata.$t = /*@__PURE__*/ markType(PopupDescriptionMetadata, 'PopupDescriptionMetadata');
    PopupDescriptionMetadata.a = null;
    return PopupDescriptionMetadata;
})();
